==> tine20-allinone_2019.12.5.tar.bz2: Addressbook/js/Addressbook-lang-fr-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: fr\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Informations professionnelles du contact"

, "Organisation / Unit"
: "Société / Service"

, "Business Address"
: "Adresse professionnelle"

, "Email"
: "Courriel"

, "Telephone Work"
: "Téléphone (professionnel)"

, "Telephone Cellphone"
: "Téléphone (portable)"

, "Telephone Car"
: "Téléphone (voiture)"

, "Telephone Fax"
: "Fax"

, "Telephone Page"
: "Pager"

, "URL"
: "Site Internet"

, "Role"
: "Fonction"

, "Room"
: "Bureau"

, "Assistant"
: "Secrétariat"

, "Assistant Telephone"
: "Téléphone secrétariat"

, "Private Contact Data"
: "Informations personnelles du contact"

, "Private Address"
: "Adresse personnelle"

, "Email Home"
: "Courriel personnel"

, "Telephone Home"
: "Téléphone domicile"

, "Telephone Cellphone Private"
: "Téléphone portable personnel"

, "Telephone Fax Home"
: "Fax personnel"

, "URL Home"
: "Site Internet"

, "Other Data"
: "Informations diverses"

, "Birthday"
: "Anniversaire"

, "Job Title"
: "Intitulé de poste"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  "Liste"
 ,"Listes"

]
, "Percent"
: ""

, "Description"
: "Description"

, "Members"
: ""

, "Type"
: "Type"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  "Répertoire"
 ,"Répertoires"

]
, "Contact, Contacts"
: [
  "contact"
 ,"contacts"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "Pays"

, "City"
: "Ville"

, "Postalcode"
: "Code postal"

, "Region"
: "Région"

, "Street"
: "Rue"

, "Street 2"
: "Rue 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "Pays (domicile)"

, "City (private)"
: "Ville (domicile)"

, "Postalcode (private)"
: "Code postal (domicile)"

, "Region (private)"
: "Région (domicile)"

, "Street (private)"
: "Rue (domicile)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "Courriel (personnel)"

, "Free/Busy URI"
: ""

, "Geo"
: "Localisation géographique"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""
 ,""

]
, "Note"
: "Note"

, "Last Name"
: "Nom"

, "Display Name"
: "Nom affiché"

, "Full Name"
: "Nom complet"

, "First Name"
: "Prénom"

, "Middle Name"
: "Deuxième prénom"

, "Title"
: "Titre"

, "Suffix"
: "Suffixe"

, "Company"
: "Société"

, "Unit"
: "Service"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Fonction"

, "Salutation"
: "Civilité"

, "syncBackendIds"
: ""

, "Car phone"
: "Téléphone de voiture"

, "Mobile"
: "Portable"

, "Mobile (private)"
: "Portable (personnel)"

, "Fax"
: "Fax"

, "Fax (private)"
: "Fax (personnel)"

, "Phone (private)"
: "Téléphone (personnel)"

, "Pager"
: "Pager"

, "Phone"
: "Téléphone"

, "Timezone"
: "Fuseau horaire"

, "Web"
: "Site Internet"

, "URL (private)"
: "Site Internet (personnel)"

, "Label"
: ""

, "Lists"
: "Listes"

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "Informations de contact"

, "Company Address"
: "Adresse professionnelle"

, "New Contact"
: "Nouveau contact"

, "ID"
: ""

, "Name"
: "Nom"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: "Importer des contacts"

, "Contact of a user account"
: "Compte utilisateur"

, "No name"
: ""

, "Business"
: ""

, "Private"
: "Privé"

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Marqueurs"

, "List Roles"
: ""

, "Street (Company Address)"
: "Rue (bureau)"

, "Street 2 (Company Address)"
: "Rue 2 (bureau)"

, "City (Company Address)"
: "Ville (bureau)"

, "Region (Company Address)"
: "Région (bureau)"

, "Postal Code (Company Address)"
: "Code postal (bureau)"

, "Country (Company Address)"
: "Pays (bureau)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Rue (domicile)"

, "Street 2 (Private Address)"
: "Rue 2 (domicile)"

, "City (Private Address)"
: "Ville (domicile)"

, "Region (Private Address)"
: "Région (domicile)"

, "Postal Code (Private Address)"
: "Code postal (domicile)"

, "Country (Private Address)"
: "Pays (domicile)"

, "Company Communication"
: "Communication d'entreprise"

, "Private Communication"
: "Communication personnelle"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (personnel)"

, "Web (private)"
: "Site Internet (personnel)"

, "Contacts"
: "Contacts"

, "Addressbooks"
: "Répertoires"

, "User Account"
: "Compte d'utilisateur"

, "Quick Search"
: "Recherche rapide"

, "Postal Code"
: "Code postal"

, "Last Modified Time"
: "Dernière modification"

, "Last Modified By"
: "Dernier modificateur"

, "Creation Time"
: "Date de création"

, "Created By"
: "Créateur"

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Saisir une description"

, "{0} must be given"
: ""

, "Member of List"
: "Liste des membres"

, "Map"
: "Carte"

, "Company address"
: "Adresse de l'entreprise"

, "Private address"
: "Adresse personnelle"

, "CardDAV URL"
: "URL pour CardDAV"

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Informations personnelles"

, "Parse address"
: "Récupérer l'adresse"

, "Print contact"
: ""

, "Paste address"
: "Coller l'adresse"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "End token mode"

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: "Tous les contacts"

, "Default Addressbook"
: "Répertoire par défaut"

, "The default addressbook for new contacts"
: "Répertoire par défaut pour les nouveaux contacts"

, "Default Favorite"
: "Favoris par défauts"

, "The default favorite which is loaded on addressbook startup"
: "Filtre utilisé lors de l'ouverture du répertoire"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: "Doublons dans les champs du contact"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Ces informations sont obligatoires pour la création d'un nouveau contact. En cas de doublon, une erreur se produit."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Civilités disponibles"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Civilités disponibles. Attention, certains choix peuvent affecter la synchronisation ou l'export vers d'autres gestionnaires de répertoires."

, "Mr"
: "M"

, "Ms"
: "Mme"

, "Parsing rules for addresses"
: "Règles de formattage des adresses"

, "Path to a XML file with address parsing rules."
: "Chemin vers le fichier XML qui contient les règles de formattage des adresses"

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Import de contact depuis VCARD"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Liste d'import (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Contacts importés le ###CURRENTDATE### à ###CURRENTTIME### par ###USERFULLNAME###"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "Import de contact depuis CSV Outlook 2007"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Import de contact depuis CSV Outlook"

, "Contact CSV import from mac address book"
: "Import de contact depuis CSV Apple MAc"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Importer les contacts du répertoire Google "

, "manage shared addressbooks"
: "gérer les répertoires partagés"

, "Create new shared addressbook folders"
: "Ajouter des répertoires partagés"

, "manage shared addressbook favorites"
: "gérer les répertoires partagés favoris"

, "Create or update shared addressbook favorites"
: "Créer ou mettre à jour les filtres du répertoire partagé"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "%s's personal addressbook"
: "Répertoire personnel de %s"

, "All contacts I have read grants for"
: "Tous les contacts auxquels j'ai accès"

, "My company"
: "Mon entreprise"

, "All coworkers in my company"
: "Tous les collaborateurs de mon entreprise"

, "My contacts"
: "Mes contacts"

, "All contacts in my Addressbooks"
: "Tout mon répertoire"

, "Last modified by me"
: "Dernièrement modifié par moi"

, "All contacts that I have last modified"
: "Tous les contact que j'ai dernièrement modifié"

, "Internal Contacts"
: "Contacts internes"

, "List"
: "Liste"

, "Addressbook"
: "Répertoire"

, "Contact"
: "contact"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Addressbook/js/Addressbook-lang-fr-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Map"
: "Carte"

, "Preferred Address"
: ""

, "Personal Information"
: "Informations personnelles"

, "Salutation"
: "Civilité"

, "Title"
: "Titre"

, "Short Name"
: ""

, "First Name"
: "Prénom"

, "Middle Name"
: "Deuxième prénom"

, "Last Name"
: "Nom"

, "Company"
: "Société"

, "Unit"
: "Service"

, "Display Name"
: "Nom affiché"

, "Industry, Industries"
: [
  ""
 ,""

]
, "Job Title"
: "Intitulé de poste"

, "Birthday (private)"
: ""

, "Contact Information"
: "Informations de contact"

, "Phone"
: "Téléphone"

, "Mobile"
: "Portable"

, "Fax"
: "Fax"

, "Phone (private)"
: "Téléphone (personnel)"

, "Mobile (private)"
: "Portable (personnel)"

, "Fax (private)"
: "Fax (personnel)"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (personnel)"

, "Web"
: "Site Internet"

, "Company Address"
: "Adresse professionnelle"

, "Street"
: "Rue"

, "Street 2"
: "Rue 2"

, "Region"
: "Région"

, "Postal Code"
: "Code postal"

, "City"
: "Ville"

, "Country"
: "Pays"

, "Private Address"
: "Adresse personnelle"

, "Description"
: "Description"

, "Enter description"
: "Saisir une description"

, "Groups"
: ""

, "Parse address"
: "Récupérer l'adresse"

, "Print contact"
: ""

, "Paste address"
: "Coller l'adresse"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "End token mode"

, "Customfields"
: ""

, "Related to"
: ""

, "Mailing List"
: ""

, "This group is a mailing list"
: ""

, "Keep copy of group mails"
: ""

, "Forward external mails"
: ""

, "Only forward member mails"
: ""

, "Only forward to system email accounts"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Contact, Contacts"
: [
  "contact"
 ,"contacts"

]
, "Members"
: ""

, "Search for members ..."
: ""

, "List Roles"
: ""

, "Remove Member"
: ""

, "CardDAV URL"
: "URL pour CardDAV"

, "New Contact"
: "Nouveau contact"

, "Addressbook, Addressbooks"
: [
  "Répertoire"
 ,"Répertoires"

]
, "ID"
: ""

, "Name"
: "Nom"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Private"
: "Privé"

, "The grant to access contacts private information"
: ""

, "Contact Personal Grant, Contact Personal Grants"
: [
  ""
 ,""

]
, "List Personal Grant, List Personal Grants"
: [
  ""
 ,""

]
, "List Information"
: ""

, "List type"
: ""

, "System accounts only"
: ""

, "{0} must be given"
: ""

, "List Functions"
: ""

, "Suffix"
: "Suffixe"

, "Birthday"
: "Anniversaire"

, "Job Role"
: "Fonction"

, "Room"
: "Bureau"

, "Street (Company Address)"
: "Rue (bureau)"

, "Street 2 (Company Address)"
: "Rue 2 (bureau)"

, "City (Company Address)"
: "Ville (bureau)"

, "Region (Company Address)"
: "Région (bureau)"

, "Postal Code (Company Address)"
: "Code postal (bureau)"

, "Country (Company Address)"
: "Pays (bureau)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Rue (domicile)"

, "Street 2 (Private Address)"
: "Rue 2 (domicile)"

, "City (Private Address)"
: "Ville (domicile)"

, "Region (Private Address)"
: "Région (domicile)"

, "Postal Code (Private Address)"
: "Code postal (domicile)"

, "Country (Private Address)"
: "Pays (domicile)"

, "Company Communication"
: "Communication d'entreprise"

, "Private Communication"
: "Communication personnelle"

, "Web (private)"
: "Site Internet (personnel)"

, "Contacts"
: "Contacts"

, "Addressbooks"
: "Répertoires"

, "User Account"
: "Compte d'utilisateur"

, "Quick Search"
: "Recherche rapide"

, "Type"
: "Type"

, "Last Modified Time"
: "Dernière modification"

, "Last Modified By"
: "Dernier modificateur"

, "Creation Time"
: "Date de création"

, "Created By"
: "Créateur"

, "List, Lists"
: [
  "Liste"
 ,"Listes"

]
, "Lists"
: "Listes"

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "GENDER_List Function"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "Business"
: ""

, "Import contacts"
: "Importer des contacts"

, "Contact of a user account"
: "Compte utilisateur"

, "No name"
: ""

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Marqueurs"

, "Full Name"
: "Nom complet"

, "Postalcode"
: "Code postal"

, "Street (private)"
: "Rue (domicile)"

, "City (private)"
: "Ville (domicile)"

, "Region (private)"
: "Région (domicile)"

, "Postalcode (private)"
: "Code postal (domicile)"

, "Country (private)"
: "Pays (domicile)"

, "Email"
: "Courriel"

, "Car phone"
: "Téléphone de voiture"

, "Pager"
: "Pager"

, "Email (private)"
: "Courriel (personnel)"

, "URL (private)"
: "Site Internet (personnel)"

, "Note"
: "Note"

, "Timezone"
: "Fuseau horaire"

, "Geo"
: "Localisation géographique"

, "Select list"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Company address"
: "Adresse de l'entreprise"

, "Private address"
: "Adresse personnelle"

, "Member E-Mails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "All contacts"
: "Tous les contacts"

, "Default Addressbook"
: "Répertoire par défaut"

, "The default addressbook for new contacts"
: "Répertoire par défaut pour les nouveaux contacts"

, "Default Favorite"
: "Favoris par défauts"

, "The default favorite which is loaded on addressbook startup"
: "Filtre utilisé lors de l'ouverture du répertoire"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Mailinglists"
: ""

, "Make group and lists to mailinglists"
: ""

, "Addressbook Short Names"
: ""

, "Add Short Name field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact (id) representing this installation"
: ""

, "Contact duplicate check fields"
: "Doublons dans les champs du contact"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Ces informations sont obligatoires pour la création d'un nouveau contact. En cas de doublon, une erreur se produit."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Civilités disponibles"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Civilités disponibles. Attention, certains choix peuvent affecter la synchronisation ou l'export vers d'autres gestionnaires de répertoires."

, "Mr"
: "M"

, "Ms"
: "Mme"

, "Parsing rules for addresses"
: "Règles de formattage des adresses"

, "Path to a XML file with address parsing rules."
: "Chemin vers le fichier XML qui contient les règles de formattage des adresses"

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Site Filter"
: ""

, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
: ""

, "Sync Backends"
: ""

, "Default telephone country code"
: ""

, "%s's personal addressbook"
: "Répertoire personnel de %s"

, "Business Contact Data"
: "Informations professionnelles du contact"

, "Organisation / Unit"
: "Société / Service"

, "Business Address"
: "Adresse professionnelle"

, "Telephone Work"
: "Téléphone (professionnel)"

, "Telephone Cellphone"
: "Téléphone (portable)"

, "Telephone Car"
: "Téléphone (voiture)"

, "Telephone Fax"
: "Fax"

, "Telephone Page"
: "Pager"

, "URL"
: "Site Internet"

, "Role"
: "Fonction"

, "Assistant"
: "Secrétariat"

, "Assistant Telephone"
: "Téléphone secrétariat"

, "Private Contact Data"
: "Informations personnelles du contact"

, "Email Home"
: "Courriel personnel"

, "Telephone Home"
: "Téléphone domicile"

, "Telephone Cellphone Private"
: "Téléphone portable personnel"

, "Telephone Fax Home"
: "Fax personnel"

, "URL Home"
: "Site Internet"

, "Other Data"
: "Informations diverses"

, "OpenDocument all data"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "Word letter"
: ""

, "PDF details"
: ""

, "Excel all data"
: ""

, "VCard Report"
: ""

, "Export multiple addressbooks to vcf files"
: ""

, "Relations"
: ""

, "CSV all data"
: ""

, "VCard/VCF"
: ""

, "Export contact data into vcf file"
: ""

, "Addressbooks to export"
: ""

, "Export target"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Import de contact depuis CSV Outlook"

, "Contact CSV import from mac address book"
: "Import de contact depuis CSV Apple MAc"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "Import de contact depuis CSV Outlook 2007"

, "Import CSV formated contacts from Outlook 2010 German address book"
: ""

, "CSV Outlook 2010 German"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Import de contact depuis VCARD"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Liste d'import (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Contacts importés le ###CURRENTDATE### à ###CURRENTTIME### par ###USERFULLNAME###"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Importer les contacts du répertoire Google "

, "GENDER_List"
: ""

, "Name/Email"
: ""

, "GENDER_Contact"
: ""

, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Longitude"
: ""

, "Latitude"
: ""

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Free/Busy URI"
: ""

, "Paths"
: ""

, "syncBackendIds"
: ""

, "Label"
: ""

, "It is not allowed to add non-account contacts to this list"
: ""

, "E-Mail address is already given. Please choose another one."
: ""

, "It is not allowed to delete a contact linked to an user account!"
: ""

, "This Short Name already exists. How about {0}?"
: ""

, "Internal Contacts"
: "Contacts internes"

, "All contacts I have read grants for"
: "Tous les contacts auxquels j'ai accès"

, "My company"
: "Mon entreprise"

, "All coworkers in my company"
: "Tous les collaborateurs de mon entreprise"

, "My contacts"
: "Mes contacts"

, "All contacts in my Addressbooks"
: "Tout mon répertoire"

, "Last modified by me"
: "Dernièrement modifié par moi"

, "All contacts that I have last modified"
: "Tous les contact que j'ai dernièrement modifié"

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "manage shared addressbooks"
: "gérer les répertoires partagés"

, "Create new shared addressbook folders"
: "Ajouter des répertoires partagés"

, "manage shared addressbook favorites"
: "gérer les répertoires partagés favoris"

, "Create or update shared addressbook favorites"
: "Créer ou mettre à jour les filtres du répertoire partagé"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Manage list email options"
: ""

, "Manage list email options like mailing lists"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "28"
: ""

, "20"
: ""

, "00877546"
: ""

, "en-GB"
: ""

, "00813B4E"
: ""

, "Gruppenrollen"
: ""

, "00DA3FCD"
: ""

, "00997199"
: ""

, "0009326B"
: ""

, "008C27A5"
: ""

, "00C96397"
: ""

, "00046462"
: ""

, "Relation, Relations"
: [
  ""
 ,""


]
, "Industry"
: ""

, "Contact"
: "contact"

, "Addressbook"
: "Répertoire"

, "Structure"
: ""

, "Contact Personal Grant"
: ""

, "List Personal Grant"
: ""

, "List"
: "Liste"

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
